@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Prereqs::CheckCircular;
 
-our $DATE = '2016-09-29'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2016-10-07'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -29,24 +29,33 @@ sub _list_my_modules {
 sub setup_installer {
     my ($self) = @_;
 
+    if ($ENV{DZIL_CHECKCIRCULAR_SKIP}) {
+        $self->log(["Skipping checking circular dependency because ".
+                        "environment DZIL_CHECKCIRCULAR_SKIP is set to true"]);
+        return;
+    }
+
     my $prereqs_hash = $self->zilla->prereqs->as_string_hash;
     my $rr_prereqs = $prereqs_hash->{runtime}{requires} // {};
+    my @prereqs = grep { $_ ne 'perl' } sort keys %$rr_prereqs;
+    return unless @prereqs;
 
     my $my_mods = $self->_list_my_modules;
 
-    $self->log_debug(
+    # since this can take several seconds, we log at non-debug level to show
+    # message to user
+    $self->log(
         ["We are depending on these modules (RuntimeRequires): ".
              "%s, checking for circularity from local CPAN mirror (whether ".
-             "these dependencies depend back to us)", $rr_prereqs]);
+                 "these dependencies depend back to us)", \@prereqs]);
+
     # skip unknown modules
-    my $res = call_lcpan_script(argv=>[
-        "mods", "--or", "-x",
-        grep {$_ ne 'perl'} keys %$rr_prereqs]);
+    my $res = call_lcpan_script(argv=>["mods", "--or", "-x", @prereqs]);
     $self->log_fatal(["Can't lcpan mods -x: %s - %s", $res->[0], $res->[1]])
         unless $res->[0] == 200;
     my $mods = $res->[2];
-    $res = call_lcpan_script(argv=>[
-        "deps", "-R", @$mods]);
+
+    $res = call_lcpan_script(argv=>["deps", "-R", @$mods]);
     $self->log_fatal(["Can't lcpan deps: %s - %s", $res->[0], $res->[1]])
         unless $res->[0] == 200;
     for my $entry (@{$res->[2]}) {
@@ -77,7 +86,7 @@ Dist::Zilla::Plugin::Prereqs::CheckCircular - Check for circular/recursive depen
 
 =head1 VERSION
 
-This document describes version 0.002 of Dist::Zilla::Plugin::Prereqs::CheckCircular (from Perl distribution Dist-Zilla-Plugin-Prereqs-CheckCircular), released on 2016-09-29.
+This document describes version 0.003 of Dist::Zilla::Plugin::Prereqs::CheckCircular (from Perl distribution Dist-Zilla-Plugin-Prereqs-CheckCircular), released on 2016-10-07.
 
 =head1 SYNOPSIS
 
@@ -89,12 +98,18 @@ In F<dist.ini>:
 
 This plugin will check that there is no circular dependency being formed. This
 is done by: collecting all RuntimeRequires prereqs of the distribution, then
-feeding it to L<App::lcpan> to get the recursive dependencies of those prereqs.
-If one of those dependencies is one of the distribution's modules, then we have
-a circular dependency and the build is aborted.
+feeding them to L<App::lcpan> to get the recursive dependencies of those
+prereqs. If one of those dependencies is one of the distribution's modules, then
+we have a circular dependency and the build is aborted.
 
 =for Pod::Coverage .+
 
+=head1 ENVIRONMENT
+
+=head2 DZIL_CHECKCIRCULAR_SKIP => bool
+
+Can be set to 1 to skip checking circular dependency.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla-Plugin-Prereqs-CheckCircular>.
